FHUFocusScopeExtension extension

Focus helpers for reading and updating the nearest FocusScopeNode.

on

Properties

focusScope FocusScopeNode

Available on BuildContext, provided by the FHUFocusScopeExtension extension

Returns the nearest FocusScopeNode that encloses this context.
no setter
focusScopeNoDependency FocusScopeNode

Available on BuildContext, provided by the FHUFocusScopeExtension extension

Same as focusScope, but does not register an inherited dependency.
no setter
hasFocus bool

Available on BuildContext, provided by the FHUFocusScopeExtension extension

Whether this node has input focus.
no setter
hasPrimaryFocus bool

Available on BuildContext, provided by the FHUFocusScopeExtension extension

Returns true if this node currently has the application-wide input focus.
no setter
unfocusCall VoidCallback

Available on BuildContext, provided by the FHUFocusScopeExtension extension

A callback that calls unfocus.
no setter

Methods

unfocus({UnfocusDisposition disposition = UnfocusDisposition.scope}) → void

Available on BuildContext, provided by the FHUFocusScopeExtension extension

Removes focus from the currently focused node.