FHUNumExtensions extension

various extension on numbers for flutter

on

Properties

allCircular BorderRadius

Available on num, provided by the FHUNumExtensions extension

Creates a BorderRadius with the same radius for all corners.
no setter
beveledRectangleBorderCircular BeveledRectangleBorder

Available on num, provided by the FHUNumExtensions extension

Creates a BeveledRectangleBorder with a circular shape for each corner.
no setter
circular Radius

Available on num, provided by the FHUNumExtensions extension

Creates a Radius with a circular shape.
no setter
constraints BoxConstraints

Available on num, provided by the FHUNumExtensions extension

Returns a BoxConstraints with this value as the minimum width and height.
no setter
continuousRectangleBorderCircular ContinuousRectangleBorder

Available on num, provided by the FHUNumExtensions extension

Creates a ContinuousRectangleBorder with a circular shape for each corner.
no setter
diagonalBLTR BorderRadius

Available on num, provided by the FHUNumExtensions extension

Creates a BorderRadius with only the bottom-left and top-right corners rounded.
no setter
diagonalTLBR BorderRadius

Available on num, provided by the FHUNumExtensions extension

Creates a BorderRadius with only the top-left and bottom-right corners rounded.
no setter
edgeInsetsAll EdgeInsets

Available on num, provided by the FHUNumExtensions extension

Returns EdgeInsets with this value applied to all sides.
no setter
edgeInsetsBottom EdgeInsets

Available on num, provided by the FHUNumExtensions extension

Returns EdgeInsets with only the bottom padding set to this value.
no setter
edgeInsetsHorizontal EdgeInsets

Available on num, provided by the FHUNumExtensions extension

Returns EdgeInsets with this value applied horizontally (left & right).
no setter
edgeInsetsLeft EdgeInsets

Available on num, provided by the FHUNumExtensions extension

Returns EdgeInsets with only the left padding set to this value.
no setter
edgeInsetsRight EdgeInsets

Available on num, provided by the FHUNumExtensions extension

Returns EdgeInsets with only the right padding set to this value.
no setter
edgeInsetsTop EdgeInsets

Available on num, provided by the FHUNumExtensions extension

Returns EdgeInsets with only the top padding set to this value.
no setter
edgeInsetsVertical EdgeInsets

Available on num, provided by the FHUNumExtensions extension

Returns EdgeInsets with this value applied vertically (top & bottom).
no setter
maxConstraints BoxConstraints

Available on num, provided by the FHUNumExtensions extension

Returns a BoxConstraints with this value as the maximum width and height.
no setter
onlyBottomRounded BorderRadius

Available on num, provided by the FHUNumExtensions extension

Creates a BorderRadius with only the bottom-left and bottom-right corners rounded.
no setter
onlyLeftRounded BorderRadius

Available on num, provided by the FHUNumExtensions extension

Creates a BorderRadius with only the top-left and bottom-left corners rounded.
no setter
onlyRightRounded BorderRadius

Available on num, provided by the FHUNumExtensions extension

Creates a BorderRadius with only the top-right and bottom-right corners rounded.
no setter
onlyTopRounded BorderRadius

Available on num, provided by the FHUNumExtensions extension

Creates a BorderRadius with only the top-left and top-right corners rounded.
no setter
rotateX Matrix4

Available on num, provided by the FHUNumExtensions extension

Creates a Matrix4 for rotation around the X-axis (in radians).
no setter
rotateY Matrix4

Available on num, provided by the FHUNumExtensions extension

Creates a Matrix4 for rotation around the Y-axis (in radians).
no setter
rotateZ Matrix4

Available on num, provided by the FHUNumExtensions extension

Creates a Matrix4 for rotation around the Z-axis (in radians).
no setter
roundedRectangleBorderCircular RoundedRectangleBorder

Available on num, provided by the FHUNumExtensions extension

Creates a RoundedRectangleBorder with a circular shape for each corner.
no setter
scaleUniform Matrix4

Available on num, provided by the FHUNumExtensions extension

Creates a Matrix4 for scaling uniformly in all directions.
no setter
scaleX Matrix4

Available on num, provided by the FHUNumExtensions extension

Creates a Matrix4 for scaling in the X direction.
no setter
scaleY Matrix4

Available on num, provided by the FHUNumExtensions extension

Creates a Matrix4 for scaling in the Y direction.
no setter
scaleZ Matrix4

Available on num, provided by the FHUNumExtensions extension

Creates a Matrix4 for scaling in the Z direction.
no setter
size Size

Available on num, provided by the FHUNumExtensions extension

Returns a Size object from the given value.
no setter
skewX Matrix4

Available on num, provided by the FHUNumExtensions extension

Creates a Matrix4 for skewing along the X-axis by this value (in radians).
no setter
skewY Matrix4

Available on num, provided by the FHUNumExtensions extension

Creates a Matrix4 for skewing along the Y-axis by this value (in radians).
no setter
translateX Matrix4

Available on num, provided by the FHUNumExtensions extension

Creates a Matrix4 for translation along the X-axis.
no setter
translateY Matrix4

Available on num, provided by the FHUNumExtensions extension

Creates a Matrix4 for translation along the Y-axis.
no setter
translateZ Matrix4

Available on num, provided by the FHUNumExtensions extension

Creates a Matrix4 for translation along the Z-axis.
no setter

Methods

borderAll({required Color color}) Border

Available on num, provided by the FHUNumExtensions extension

Creates a Border with the given width and color.
borderAllWithStyle({required Color color, required BorderStyle style}) Border

Available on num, provided by the FHUNumExtensions extension

Creates a Border with the given width, color, and style.
borderBottom({required Color color}) Border

Available on num, provided by the FHUNumExtensions extension

Creates a Border with only the bottom side having the given width and color.
borderLeft({required Color color}) Border

Available on num, provided by the FHUNumExtensions extension

Creates a Border with only the left side having the given width and color.
borderRight({required Color color}) Border

Available on num, provided by the FHUNumExtensions extension

Creates a Border with only the right side having the given width and color.
borderTop({required Color color}) Border

Available on num, provided by the FHUNumExtensions extension

Creates a Border with only the top side having the given width and color.
heightBox({Widget? child}) SizedBox

Available on num, provided by the FHUNumExtensions extension

Returns a SizedBox with the given height and optional child.
paddingAll({required Widget child}) Widget

Available on num, provided by the FHUNumExtensions extension

Returns a Padding widget with this value applied to all sides.
paddingBottom({required Widget child}) Widget

Available on num, provided by the FHUNumExtensions extension

Returns a Padding widget with only the bottom padding set to this value.
paddingHorizontal({required Widget child}) Widget

Available on num, provided by the FHUNumExtensions extension

Returns a Padding widget with this value applied horizontally (left & right).
paddingLeft({required Widget child}) Widget

Available on num, provided by the FHUNumExtensions extension

Returns a Padding widget with only the left padding set to this value.
paddingRight({required Widget child}) Widget

Available on num, provided by the FHUNumExtensions extension

Returns a Padding widget with only the right padding set to this value.
paddingTop({required Widget child}) Widget

Available on num, provided by the FHUNumExtensions extension

Returns a Padding widget with only the top padding set to this value.
paddingVertical({required Widget child}) Widget

Available on num, provided by the FHUNumExtensions extension

Returns a Padding widget with this value applied vertically (top & bottom).
radiusLTRB(num topLeft, num topRight, num bottomRight, num bottomLeft) BorderRadius

Available on num, provided by the FHUNumExtensions extension

Creates a BorderRadius with different radii for each corner.
squareBox({Widget? child}) SizedBox

Available on num, provided by the FHUNumExtensions extension

Returns a square SizedBox with the given dimensions and optional child.
widthBox({Widget? child}) SizedBox

Available on num, provided by the FHUNumExtensions extension

Returns a SizedBox with the given width and optional child.