ThemeWithoutEffects class

A widget that optionally removes various visual feedback effects from its child subtree.

This widget wraps its child in a Theme with modified theme data. The modifications include optionally setting the following properties to transparent:

  • splashColor
  • highlightColor
  • hoverColor
  • dividerColor
  • focusColor

Additionally, it optionally replaces the splashFactory with a custom implementation that prevents splash effects from being generated.

Use this widget to selectively disable visual feedback in specific parts of your application where such effects are not desired.

Inheritance

Constructors

ThemeWithoutEffects({required Widget child, bool noSplashColor = true, bool noHighlightColor = true, bool noHoverColor = true, bool noDividerColor = true, bool noFocusColor = true, bool noSplashFactory = true, Key? key})
Creates a ThemeWithoutEffects widget.
const

Properties

child Widget
The widget subtree to apply the effect to.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
noDividerColor bool
Whether to remove the dividerColor effect.
final
noFocusColor bool
Whether to remove the focusColor effect.
final
noHighlightColor bool
Whether to remove the highlightColor effect.
final
noHoverColor bool
Whether to remove the hoverColor effect.
final
noSplashColor bool
Whether to remove the splashColor effect.
final
noSplashFactory bool
Whether to remove the splashFactory effect.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited